@@ -13,6 +13,7 @@ LOG_PATH = os.environ.get('LOG_PATH')
 TARGET_RESOLUTION = int(os.environ.get('TARGET_RESOLUTION'))
 BATCH_SIZE = int(os.environ.get('BATCH_SIZE'))
 EPOCHS = int(os.environ.get('EPOCHS'))
+INCLUDE_TOP = bool(os.environ.get('INCLUDE_TOP'))
 
 MAX_IMAGES_TO_VECTORIZE = int(os.environ.get('MAX_IMAGES_TO_VECTORIZE'))
 MAX_SIMILARITY_RESULT_NUMBER = int(os.environ.get('MAX_SIMILARITY_RESULT_NUMBER'))
@@ -75,14 +76,27 @@ BASE_DIR = os.environ.get('BASE_DIR')
 PATH_EMAIL_CUSTOMER = os.path.join(BASE_DIR, os.environ.get('CUSTOMER_EMAIL'))
 PATH_INSCRIPTION_EMAIL_CUSTOMER = os.path.join(BASE_DIR, os.environ.get('INSCRIPTION_EMAIL'))
 PATH_EMAIL_TRINING_STARTED_CMS = os.path.join(BASE_DIR, os.environ.get('EMAIL_TRINING_STARTED_CMS'))
-PATH_EMAIL_TRAINING_STARTED_CUSTOMER = os.path.join(BASE_DIR, "webserver/users_management/webserverapp/templates/emails/email_of_started_training.html")
-PATH_EMAIL_CLIENT_INSCRIPTION = os.path.join(BASE_DIR, "webserver/users_management/webserverapp/templates/emails/client_inscription.html")
-PATH_EMAIL_RESET_PASSWORD = os.path.join(BASE_DIR, "webserver/users_management/webserverapp/templates/emails/reset_password.html")
-PATH_EMAIL_ACTIVATE_ACCOUNT = os.path.join(BASE_DIR, "webserver/users_management/webserverapp/templates/emails/acc_active_email.html")
-PATH_EMAIL_CONTACT = os.path.join(BASE_DIR, "webserver/users_management/webserverapp/templates/emails/contact_from_customer.html")
-PATH_EMAIL_ACTIVATE_ACCOUNT_SHOPIFY_PAYMENT = os.path.join(BASE_DIR, "webserver/users_management/webserverapp/templates/emails/activate_shopify_payment.html")
-PATH_EMAIL_PROBLEM_SHOPIFY_PAYMENT = os.path.join(BASE_DIR, "webserver/users_management/webserverapp/templates/emails/problem_shopify_payment.html")
-PATH_EMAIL_TO_CLIENT = os.path.join(BASE_DIR, "webserver/users_management/webserverapp/templates/emails/email_to_client.html")
+PATH_EMAIL_TRAINING_STARTED_CUSTOMER = os.path.join(BASE_DIR,
+                                                    "webserver/users_management/webserverapp/templates/"
+                                                    "emails/email_of_started_training.html")
+PATH_EMAIL_CLIENT_INSCRIPTION = os.path.join(BASE_DIR,
+                                             "webserver/users_management/webserverapp/templates/emails/"
+                                             "client_inscription.html")
+PATH_EMAIL_RESET_PASSWORD = os.path.join(BASE_DIR,
+                                         "webserver/users_management/webserverapp/templates/emails/reset_password.html")
+PATH_EMAIL_ACTIVATE_ACCOUNT = os.path.join(BASE_DIR,
+                                           "webserver/users_management/webserverapp/templates/emails/"
+                                           "acc_active_email.html")
+PATH_EMAIL_CONTACT = os.path.join(BASE_DIR,
+                                  "webserver/users_management/webserverapp/templates/emails/contact_from_customer.html")
+PATH_EMAIL_ACTIVATE_ACCOUNT_SHOPIFY_PAYMENT = os.path.join(BASE_DIR,
+                                                           "webserver/users_management/webserverapp/templates/"
+                                                           "emails/activate_shopify_payment.html")
+PATH_EMAIL_PROBLEM_SHOPIFY_PAYMENT = os.path.join(BASE_DIR,
+                                                  "webserver/users_management/webserverapp/templates/emails/"
+                                                  "problem_shopify_payment.html")
+PATH_EMAIL_TO_CLIENT = os.path.join(BASE_DIR,
+                                    "webserver/users_management/webserverapp/templates/emails/email_to_client.html")
 
 SMTP_USERNAME = os.environ.get('SMTP_USERNAME')
 SMTP_PASSWORD = os.environ.get('SMTP_PASSWORD')
@@ -132,11 +146,11 @@ class Config(object):
 STRIPE_PKEY = os.environ.get('STRIPE_PKEY')
 STRIPE_SKEY = os.environ.get('STRIPE_SKEY')
 
-#SECRET KEY
+# SECRET KEY
 SECRET_KEY = os.environ.get('SECRET_KEY')
 ADMIN_KEY = os.environ.get('ADMIN_KEY')
 
-TRAINING_STEPS = int(os.environ.get('TRAINING_STEPS')) if os.environ.get('TRAINING_STEPS') else 100
+TRAINING_STEPS = int(os.environ.get('TRAINING_STEPS', 100))
 USE_DATABASE_AZURE=bool(os.environ.get('USE_DATABASE_AZURE'))
 
 SEUIL_SIMILARITY = float(os.environ.get('SEUIL_SIMILARITY'))
