@@ -22,7 +22,7 @@ import string
 import shutil
 import tldextract
 import uuid
-
+import vatnumber
 
 api = APIFoqus()
 
@@ -1193,13 +1193,17 @@ def update_profile_customer(customer_email, customer_name, first_name, last_name
         id_profile = profile[0]
         old_name = profile[1]
         customer_type = profile[8]
-        if new_email == customer_email or new_email== "":
 
+        if new_email == customer_email or new_email== "":
             db.set_profile(table_name=DATABASE_USERS_MANAGEMENT_TABLE_NAME, firstName=first_name, lastName=last_name,
                            customerJob=job, customerPhone=phone_number, customerEmail=customer_email,
                            customer=customer_name, id=str(id_profile))
         else:
-            db.set_profile(table_name=DATABASE_USERS_MANAGEMENT_TABLE_NAME, firstName=first_name, lastName=last_name,
+            existing_profile = db.get_profile(table_name=DATABASE_USERS_MANAGEMENT_TABLE_NAME, customerEmail=new_email)
+            if existing_profile:
+                return False
+            else:
+                db.set_profile(table_name=DATABASE_USERS_MANAGEMENT_TABLE_NAME, firstName=first_name, lastName=last_name,
                            customerJob=job, customerPhone=phone_number, customerEmail=new_email,
                            customer=customer_name, id=str(id_profile))
 
@@ -1312,7 +1316,7 @@ def forget_password(customer_email):
             full_url = DOMAIN + 'reset_password/' + urlsafe_base64_encode(force_bytes(user[0])).decode('utf-8') \
                        + '/' + user[12]
 
-        send_email_for_reset_password(customer_email,full_url,first_name_of_customer,mail_subject)
+        send_email_for_reset_password(customer_email, full_url, first_name_of_customer, mail_subject)
         logger.info('A recovery email has been sent. Thank you to check your mailbox')
         return True
     except :
@@ -1323,7 +1327,7 @@ def forget_password(customer_email):
 def get_connected_customer_info(customer_email):
     result = {}
     try:
-        customer_info = db.get_profile(table_name=DATABASE_USERS_MANAGEMENT_TABLE_NAME,customerEmail=customer_email)
+        customer_info = db.get_profile(table_name=DATABASE_USERS_MANAGEMENT_TABLE_NAME, customerEmail=customer_email)
         result['customer_email'] = customer_email
         result['customer_name'] = customer_info[1]
         result['job'] = customer_info[4]
@@ -1348,12 +1352,13 @@ def delete_user_data(customer_name, customer_type):
         detection_error_projects = db.select_from_status_project(customer_name, customer_type)[0] \
             if db.select_from_status_project(customer_name, customer_type) != [] \
             else db.select_from_status_project(customer_name, customer_type)
-        for detection_table in detection_error_projects :
+        for detection_table in detection_error_projects:
             logger.info('Deleting_detection_error_table %s' % detection_table)
             db.drop_table("predict_"+customer_type+"_"+customer_name+"_"+str(detection_table.lower()))
         move_directory(INPUT_S3 + customer_type + '/' + customer_name + '/images/', 'deleted_user')
-        for file in list_repository_files(AZURE_INPUT_PATH + customer_type + '/' + customer_name + '/images/'):
-            copy_azure_file(file, AZURE_CONTAINER_NAME, "deletedUser-" + AZURE_CONTAINER_NAME)
+        for file in list_repository_files():
+            azure_move_directory(AZURE_INPUT_PATH + customer_type + '/' + customer_name + '/images/', "deletedUser-" + AZURE_CONTAINER_NAME)
+            # (file, AZURE_CONTAINER_NAME, "deletedUser-" + AZURE_CONTAINER_NAME)
         logger.info('Archiving input directory for client %s %s' % (customer_name, customer_type))
         move_directory(OUTPUT_S3 + customer_type + '/' + customer_name + '/images/', 'deleted_user')
         for file in list_repository_files(AZURE_OUTPUT_PATH + customer_type + '/' + customer_name + '/images/'):
@@ -1376,6 +1381,56 @@ def delete_user_data(customer_name, customer_type):
         db.drop_table(replace_special_caractere(customer_name).replace(' ', '_'))
         logger.info("Drop_user_table_for_similars %s" % customer_name)
         return True
+    # logger.warning('Deleting error %s' % e)
+    else:
+        return False
+
+
+def delete_user_data(customer_name, customer_type):
+    tables_to_delete_from = [CMS_TABLE, STATUS_PROJECT_TABLE,
+                             PAYMENT_TABLE, REVIEW_TABLE, HISTORY_SEARCH_TABLE, PAYMENT_INFO]
+    if db.get_customer_info_from_customer_name(customer_name):
+        if db.delete_from_users_management(customer_name, customer_type):
+            logger.info("Deleting_user %s with type %s from table %s"
+                        % (customer_name, customer_type, DATABASE_USERS_MANAGEMENT_TABLE_NAME))
+        detection_error_projects = db.select_from_status_project(customer_name, customer_type)[0] \
+            if db.select_from_status_project(customer_name, customer_type) != [] \
+            else db.select_from_status_project(customer_name, customer_type)
+        for detection_table in detection_error_projects :
+            logger.info('Deleting_detection_error_table %s' % detection_table)
+            db.drop_table("predict_"+customer_type+"_"+customer_name+"_"+str(detection_table.lower()))
+        for table in tables_to_delete_from:
+            if db.delete_from_table(table, customer_name, customer_type):
+                logger.info("Deleting_user %s with type %s from table %s" % (customer_name, customer_type, table))
+            else:
+                logger.info("Deleting_user %s with type %s from table %s failed" %
+                            (customer_name, customer_type, table))
+        db.drop_table(replace_special_caractere(customer_name).replace(' ', '_'))
+        logger.info("Drop_user_table_for_similars %s" % customer_name)
+        try:
+            move_directory(INPUT_S3 + customer_type + '/' + customer_name + '/images/', 'deleted_user')
+
+            azure_move_directory(AZURE_INPUT_PATH + customer_type + '/' + customer_name + '/images/',
+                                 "deletedUser/" + AZURE_INPUT_PATH + customer_type + '/' + customer_name + '/images/')
+            # for file in list_repository_files(AZURE_INPUT_PATH + customer_type + '/' + customer_name + '/images/'):
+            #     copy_azure_file(file, AZURE_CONTAINER_NAME, "deletedUser-" + AZURE_CONTAINER_NAME)
+            logger.info('Archiving input directory for client %s %s' % (customer_name, customer_type))
+            move_directory(OUTPUT_S3 + customer_type + '/' + customer_name + '/images/', 'deleted_user')
+            azure_move_directory(AZURE_OUTPUT_PATH + customer_type + '/' + customer_name + '/images/',
+                                 "deletedUser/" + AZURE_OUTPUT_PATH + customer_type + '/' + customer_name + '/images/')
+            logger.info('Archiving output directory for client %s %s' %(customer_name, customer_type))
+            move_directory(VECTORS_S3 + customer_type + '/' + customer_name + '/', 'deleted_user')
+            azure_move_directory(AZURE_VECTORS_PATH + customer_type + '/' + customer_name + '/images/',
+                                 "deletedUser/" + AZURE_VECTORS_PATH + customer_type + '/' + customer_name + '/images/')
+            logger.info('Archiving vectors directory for client %s %s' % (customer_name, customer_type))
+            move_directory(TRAININGS_S3 + customer_type + '/' + customer_name + '/', 'deleted_user')
+            azure_move_directory(AZURE_TRAINING_PATH + customer_type + '/' + customer_name + '/images/',
+                                 "deletedUser/" + AZURE_TRAINING_PATH + customer_type + '/' + customer_name + '/images/')
+            logger.info('Archiving training directory for client %s %s' % (customer_name, customer_type))
+        except Exception as e:
+            logger.warning('Deleting error %s' %e)
+
+        return True
     else:
         return False
 
@@ -1401,11 +1456,29 @@ def delete_user_data_from_email(customer_email):
         return False
 
 
-def save_payment_info(customer, customer_type, name, address, zipcode, country, city):
-    db.insert_or_update_payment_info(PAYMENT_INFO, customer, customer_type, name, address, zipcode, country, city)
+def save_payment_info(customer, customer_type, name, address, zipcode, country, city, tva_number):
+    db.insert_or_update_payment_info(PAYMENT_INFO, customer, customer_type, name, address, zipcode, country, city, tva_number)
     return True
 
 
+def payment_details_client(customer_name, customer_type, choosed_plan):
+
+    details_client = db.get_client_adress(PAYMENT_INFO, customer_name, customer_type)
+    plan = db.get_plan_form_name(choosed_plan)
+    client_payment = db.get_client_payment(customer_name, customer_type)
+    price_month = float(plan[3]/12)
+
+    tva_number = details_client[8]
+    if vatnumber.check_vat_fr(tva_number):
+        price_month_tva = price_month + (price_month * 0.2)
+        total = price_month_tva * 11 if client_payment[7] else price_month_tva * 12
+    else:
+        total = price_month * 11 if client_payment[7] else price_month * 12
+
+    return {"total": round(total, 2), "price_month": price_month, "tva": 1 if vatnumber.check_vat_fr(tva_number) else 0,
+            "currency": client_payment[7], "interval": "365", "testing": 0 if client_payment[7] else 1}
+
+
 def shopify_payment_billing(customer_name, customer_type, customer_email, url_cms, token_cms, plan):
     from foqus.commons import get_api_version_shopify
     from currency_converter import CurrencyConverter
@@ -1599,6 +1672,10 @@ def payment_client(customer, customer_type, email,  plan_name, tva, methode_paym
 def get_connected_customer_cms_info(customer_name, customer_type, cms):
     result = db.get_cms_details_for_client(CMS_TABLE, customer_name, customer_type, cms)
     if result:
+        if result[7]:
+            url_confirmation = result[7]
+        else:
+            url_confirmation = ''
         response = {
             'customer_name': result[1],
             'customer_type': result[2],
@@ -1606,7 +1683,7 @@ def get_connected_customer_cms_info(customer_name, customer_type, cms):
             'access_token': result[6],
             'cms_type': result[4],
             'project_name': result[3],
-            'url_confirmation': result[7]}
+            'url_confirmation': url_confirmation}
     else:
         response = {}
     return response
