@@ -147,7 +147,11 @@ def delta_retrieve_json(customer_name, customer_type, project_name):
 
     new_file_status = path_new_file + date + ".json"
 
-    paths = sorted(glob.glob(path_json + "/*.json"), key=os.path.getmtime)
+    # if there are shopify files take only shopify_file*.json
+    if len(glob.glob(path_json + "/shopify_*.json")) > 0:
+        paths = sorted(glob.glob(path_json + "/shopify_file_*.json"), key=os.path.getmtime)
+    else:
+        paths = sorted(glob.glob(path_json + "/*.json"), key=os.path.getmtime)
     if len(paths) > 1:
         last_json_path = paths[-1]
         before_last_json_path = paths[-2]
